pub struct BatchCreateParams {
pub completion_window: String,
pub endpoint: BatchCreateParamsEndpoint,
pub input_file_id: String,
pub metadata: Option<Value>,
pub output_expires_after: Option<OutputExpiresAfter>,
}Fields
completion_window: StringThe time frame within which the batch should be processed.
endpoint: BatchCreateParamsEndpointThe endpoint to be used for all requests in the batch.
input_file_id: StringThe ID of an uploaded file that contains requests for the new batch.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
output_expires_after: Option<OutputExpiresAfter>The expiration policy for the output and/or error file that are generated for a