pub struct OutputExpiresAfter {
pub anchor: String,
pub seconds: i64,
}Expand description
The expiration policy for the output and/or error file that are generated for a batch.
Fields
anchor: StringAnchor timestamp after which the expiration policy applies.
seconds: i64The number of seconds after the anchor time that the file will expire.