pub struct AssistantCreateParams {
pub model: String,
pub description: Option<String>,
pub instructions: Option<String>,
pub metadata: Option<Value>,
pub name: Option<String>,
pub reasoning_effort: Option<Value>,
pub response_format: Option<Value>,
pub temperature: Option<f64>,
pub tool_resources: Option<ToolResources>,
pub tools: Option<Vec<Value>>,
pub top_p: Option<f64>,
}Fields
model: StringID of the model to use.
description: Option<String>The description of the assistant. The maximum length is 512 characters.
instructions: Option<String>The system instructions that the assistant uses.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
name: Option<String>The name of the assistant. The maximum length is 256 characters.
reasoning_effort: Option<Value>Constrains effort on reasoning for
response_format: Option<Value>Specifies the format that the model must output.
temperature: Option<f64>What sampling temperature to use, between 0 and 2.
tool_resources: Option<ToolResources>A set of resources that are used by the assistant’s tools.
tools: Option<Vec<Value>>A list of tool enabled on the assistant.
top_p: Option<f64>An alternative to sampling with temperature, called nucleus sampling, where the