ThreadCreateAndRunParamsBase

Struct ThreadCreateAndRunParamsBase 

pub struct ThreadCreateAndRunParamsBase {
Show 15 fields pub assistant_id: String, pub instructions: Option<String>, pub max_completion_tokens: Option<i64>, pub max_prompt_tokens: Option<i64>, pub metadata: Option<Value>, pub model: Option<String>, pub parallel_tool_calls: Option<bool>, pub response_format: Option<Value>, pub temperature: Option<f64>, pub thread: Option<Thread>, pub tool_choice: Option<Value>, pub tool_resources: Option<ToolResources>, pub tools: Option<Vec<Value>>, pub top_p: Option<f64>, pub truncation_strategy: Option<TruncationStrategy>,
}

Fields

assistant_id: String

The ID of the

instructions: Option<String>

Override the default system message of the assistant.

max_completion_tokens: Option<i64>

The maximum number of completion tokens that may be used over the course of the

max_prompt_tokens: Option<i64>

The maximum number of prompt tokens that may be used over the course of the run.

metadata: Option<Value>

Set of 16 key-value pairs that can be attached to an object.

model: Option<String>

The ID of the Model to

parallel_tool_calls: Option<bool>

Whether to enable

response_format: Option<Value>

Specifies the format that the model must output.

temperature: Option<f64>

What sampling temperature to use, between 0 and 2.

thread: Option<Thread>

Options to create a new thread.

tool_choice: Option<Value>

Controls which (if any) tool is called by the model. none means the model will

tool_resources: Option<ToolResources>

A set of resources that are used by the assistant’s tools.

tools: Option<Vec<Value>>

Override the tools the assistant can use for this run.

top_p: Option<f64>

An alternative to sampling with temperature, called nucleus sampling, where the

truncation_strategy: Option<TruncationStrategy>

Controls for how a thread will be truncated prior to the run.