pub struct ThreadCreateParams {
pub messages: Option<Vec<Message>>,
pub metadata: Option<Value>,
pub tool_resources: Option<ToolResources>,
}Fields
messages: Option<Vec<Message>>A list of messages to
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
tool_resources: Option<ToolResources>A set of resources that are made available to the assistant’s tools in this