pub struct TruncationStrategy {
pub type_: TruncationStrategyType,
pub last_messages: Option<i64>,
}Expand description
Controls for how a thread will be truncated prior to the run.
Fields
type_: TruncationStrategyTypeThe truncation strategy to use for the thread.
last_messages: Option<i64>The number of most recent messages from the thread when constructing the context