pub struct ChatCompletion {
pub id: String,
pub choices: Vec<Value>,
pub created: i64,
pub model: String,
pub object: String,
pub service_tier: Option<ChatCompletionServiceTier>,
pub system_fingerprint: Option<String>,
pub usage: Option<Value>,
}Expand description
Represents a chat completion response returned by model, based on the provided input.
Fields
id: StringA unique identifier for the chat completion.
choices: Vec<Value>A list of chat completion choices.
created: i64The Unix timestamp (in seconds) of when the chat completion was created.
model: StringThe model used for the chat completion.
object: StringThe object type, which is always chat.completion.
service_tier: Option<ChatCompletionServiceTier>Specifies the processing type used for serving the request.
system_fingerprint: Option<String>This fingerprint represents the backend configuration that the model runs with.
usage: Option<Value>Usage statistics for the completion request.