pub struct ChatCompletionAudio {
pub id: String,
pub data: String,
pub expires_at: i64,
pub transcript: String,
}Expand description
If the audio output modality is requested, this object contains data
Fields
id: StringUnique identifier for this audio response.
data: StringBase64 encoded audio bytes generated by the model, in the format specified in
expires_at: i64The Unix timestamp (in seconds) for when this audio response will no longer be
transcript: StringTranscript of the audio generated by the model.