pub struct CompletionCreateFunction {
pub name: String,
pub description: Option<String>,
pub parameters: Option<Value>,
}Fields
name: StringThe name of the function to be called.
description: Option<String>A description of what the function does, used by the model to choose when and
parameters: Option<Value>The parameters the functions accepts, described as a JSON Schema object.