pub struct CompletionListParams {
pub after: Option<String>,
pub limit: Option<i64>,
pub metadata: Option<Value>,
pub model: Option<String>,
pub order: Option<CompletionListParamsOrder>,
}Fields
after: Option<String>Identifier for the last chat completion from the previous pagination request.
limit: Option<i64>Number of Chat Completions to retrieve.
metadata: Option<Value>A list of metadata keys to filter the Chat Completions by. Example:
model: Option<String>The model used to generate the Chat Completions.
order: Option<CompletionListParamsOrder>Sort order for Chat Completions by timestamp.