CompletionCreateParamsBase

Struct CompletionCreateParamsBase 

pub struct CompletionCreateParamsBase {
Show 17 fields pub model: Option<String>, pub prompt: Value, pub best_of: Option<i64>, pub echo: Option<bool>, pub frequency_penalty: Option<f64>, pub logit_bias: Option<HashMap<String, i64>>, pub logprobs: Option<i64>, pub max_tokens: Option<i64>, pub n: Option<i64>, pub presence_penalty: Option<f64>, pub seed: Option<i64>, pub stop: Option<Value>, pub stream_options: Option<Value>, pub suffix: Option<String>, pub temperature: Option<f64>, pub top_p: Option<f64>, pub user: Option<String>,
}

Fields

model: Option<String>

ID of the model to use.

prompt: Value

The prompt(s) to generate completions for, encoded as a string, array of

best_of: Option<i64>

Generates best_of completions server-side and returns the “best” (the one with

echo: Option<bool>

Echo back the prompt in addition to the completion

frequency_penalty: Option<f64>

Number between -2.0 and 2.0.

logit_bias: Option<HashMap<String, i64>>

Modify the likelihood of specified tokens appearing in the completion.

logprobs: Option<i64>

Include the log probabilities on the logprobs most likely output tokens, as

max_tokens: Option<i64>

The maximum number of tokens that can be generated in the

n: Option<i64>

How many completions to generate for each prompt.

presence_penalty: Option<f64>

Number between -2.0 and 2.0.

seed: Option<i64>

If specified, our system will make a best effort to sample deterministically,

stop: Option<Value>

Not supported with latest reasoning models o3 and o4-mini.

stream_options: Option<Value>

Options for streaming response. Only set this when you set stream: true.

suffix: Option<String>

The suffix that comes after a completion of inserted text.

temperature: Option<f64>

What sampling temperature to use, between 0 and 2.

top_p: Option<f64>

An alternative to sampling with temperature, called nucleus sampling, where the

user: Option<String>

A unique identifier representing your end-user, which can help OpenAI to monitor