pub struct ContainerCreateParams {
pub name: String,
pub expires_after: Option<ExpiresAfter>,
pub file_ids: Option<Value>,
pub memory_limit: Option<ContainerCreateParamsMemoryLimit>,
pub network_policy: Option<NetworkPolicy>,
pub skills: Option<Vec<Skill>>,
}Fields
name: StringName of the container to create.
expires_after: Option<ExpiresAfter>Container expiration time in seconds relative to the ‘anchor’ time.
file_ids: Option<Value>IDs of files to copy to the container.
memory_limit: Option<ContainerCreateParamsMemoryLimit>Optional memory limit for the container. Defaults to “1g”.
network_policy: Option<NetworkPolicy>Network access policy for the container.
skills: Option<Vec<Skill>>An optional list of skills referenced by id or inline data.