pub struct ComputerScreenshotContent {
pub detail: ComputerScreenshotContentDetail,
pub file_id: Option<String>,
pub image_url: Option<String>,
pub type_: String,
}Expand description
A screenshot of a computer.
Fields
detail: ComputerScreenshotContentDetailThe detail level of the screenshot image to be sent to the model.
file_id: Option<String>The identifier of an uploaded file that contains the screenshot.
image_url: Option<String>The URL of the screenshot image.
type_: StringSpecifies the event type.