pub struct Conversation {
pub id: String,
pub created_at: i64,
pub metadata: Value,
pub object: String,
}Fields
id: StringThe unique ID of the conversation.
created_at: i64The time at which the conversation was created, measured in seconds since the
metadata: ValueSet of 16 key-value pairs that can be attached to an object.
object: StringThe object type, which is always conversation.