pub struct LocalShellCall {
pub id: String,
pub action: LocalShellCallAction,
pub call_id: String,
pub status: LocalShellCallStatus,
pub type_: String,
}Expand description
A tool call to run a command on the local shell.
Fields
id: StringThe unique ID of the local shell call.
action: LocalShellCallActionExecute a shell command on the server.
call_id: StringThe unique ID of the local shell tool call generated by the model.
status: LocalShellCallStatusThe status of the local shell call.
type_: StringThe type of the local shell call. Always local_shell_call.