pub struct LocalShellCallOutput {
pub id: String,
pub output: String,
pub type_: String,
pub status: Option<LocalShellCallOutputStatus>,
}Expand description
The output of a local shell tool call.
Fields
id: StringThe unique ID of the local shell tool call generated by the model.
output: StringA JSON string of the output of the local shell tool call.
type_: StringThe type of the local shell tool call output. Always local_shell_call_output.
status: Option<LocalShellCallOutputStatus>The status of the item. One of in_progress, completed, or incomplete.