pub struct EmbeddingCreateParams {
pub input: Value,
pub model: String,
pub dimensions: Option<i64>,
pub encoding_format: Option<EmbeddingCreateParamsEncodingFormat>,
pub user: Option<String>,
}Fields
input: ValueInput text to embed, encoded as a string or array of tokens.
model: StringID of the model to use.
dimensions: Option<i64>The number of dimensions the resulting output embeddings should have.
encoding_format: Option<EmbeddingCreateParamsEncodingFormat>The format to return the embeddings in.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor