pub struct CreateEvalCompletionsRunDataSource {
pub source: Source,
pub type_: String,
pub input_messages: Option<InputMessages>,
pub model: Option<String>,
pub sampling_params: Option<SamplingParams>,
}Expand description
A CompletionsRunDataSource object describing a model sampling configuration.
Fields
source: SourceDetermines what populates the item namespace in this run’s data source.
type_: StringThe type of run data source. Always completions.
input_messages: Option<InputMessages>Used when sampling from a model.
model: Option<String>The name of the model to use for generating completions (e.g. “o3-mini”).
sampling_params: Option<SamplingParams>Trait Implementations
Sourceimpl Clone for CreateEvalCompletionsRunDataSource
impl Clone for CreateEvalCompletionsRunDataSource
Sourcefn clone(&self) -> CreateEvalCompletionsRunDataSource
fn clone(&self) -> CreateEvalCompletionsRunDataSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateEvalCompletionsRunDataSource
impl<'de> Deserialize<'de> for CreateEvalCompletionsRunDataSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more