pub struct DataSourceConfigCustom {
pub item_schema: HashMap<String, Value>,
pub type_: String,
pub include_sample_schema: Option<bool>,
}Expand description
A CustomDataSourceConfig object that defines the schema for the data source used for the evaluation runs.
Fields
item_schema: HashMap<String, Value>The json schema for each row in the data source.
type_: StringThe type of data source. Always custom.
include_sample_schema: Option<bool>Whether the eval should expect you to populate the sample namespace (ie, by