pub struct DataSourceCreateEvalResponsesRunDataSourceSamplingParams {
pub max_completion_tokens: Option<i64>,
pub reasoning_effort: Option<Value>,
pub seed: Option<i64>,
pub temperature: Option<f64>,
pub text: Option<DataSourceCreateEvalResponsesRunDataSourceSamplingParamsText>,
pub tools: Option<Vec<Value>>,
pub top_p: Option<f64>,
}Fields
max_completion_tokens: Option<i64>The maximum number of tokens in the generated output.
reasoning_effort: Option<Value>Constrains effort on reasoning for
seed: Option<i64>A seed value to initialize the randomness, during sampling.
temperature: Option<f64>A higher temperature increases randomness in the outputs.
text: Option<DataSourceCreateEvalResponsesRunDataSourceSamplingParamsText>Configuration options for a text response from the model.
tools: Option<Vec<Value>>An array of tools the model may call while generating a response.
top_p: Option<f64>An alternative to temperature for nucleus sampling; 1.0 includes all tokens.