pub struct DataSourceResponsesSamplingParamsText {
pub format: Option<Value>,
}Expand description
Configuration options for a text response from the model.
Fields
format: Option<Value>An object specifying the format that the model must output.