pub struct DataSourceResponsesSourceResponses {
pub type_: String,
pub created_after: Option<i64>,
pub created_before: Option<i64>,
pub instructions_search: Option<String>,
pub metadata: Option<Value>,
pub model: Option<String>,
pub reasoning_effort: Option<Value>,
pub temperature: Option<f64>,
pub tools: Option<Vec<String>>,
pub top_p: Option<f64>,
pub users: Option<Vec<String>>,
}Expand description
A EvalResponsesSource object describing a run data source configuration.
Fields
type_: StringThe type of run data source. Always responses.
created_after: Option<i64>Only include items created after this timestamp (inclusive).
created_before: Option<i64>Only include items created before this timestamp (inclusive).
instructions_search: Option<String>Optional string to search the ‘instructions’ field.
metadata: Option<Value>Metadata filter for the responses.
model: Option<String>The name of the model to find responses for.
reasoning_effort: Option<Value>Constrains effort on reasoning for
temperature: Option<f64>Sampling temperature. This is a query parameter used to select responses.
tools: Option<Vec<String>>List of tool names. This is a query parameter used to select responses.
top_p: Option<f64>Nucleus sampling parameter. This is a query parameter used to select responses.
users: Option<Vec<String>>List of user identifiers. This is a query parameter used to select responses.