pub struct EvalCreateParams {
pub data_source_config: DataSourceConfig,
pub testing_criteria: Vec<TestingCriterion>,
pub metadata: Option<Value>,
pub name: Option<String>,
}Fields
data_source_config: DataSourceConfigThe configuration for the data source used for the evaluation runs.
testing_criteria: Vec<TestingCriterion>A list of graders for all eval runs in this group.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
name: Option<String>The name of the evaluation.