pub struct EvalCustomDataSourceConfig {
pub schema_: HashMap<String, Value>,
pub type_: String,
}Expand description
A CustomDataSourceConfig which specifies the schema of your item and optionally sample namespaces.
Fields
schema_: HashMap<String, Value>The json schema for the run data source items. Learn how to build JSON schemas
type_: StringThe type of data source. Always custom.