pub struct EvalRetrieveResponse {
pub id: String,
pub created_at: i64,
pub data_source_config: DataSourceConfig,
pub metadata: Option<Value>,
pub name: String,
pub object: String,
pub testing_criteria: Vec<TestingCriterion>,
}Expand description
An Eval object with a data source config and testing criteria.
Fields
id: StringUnique identifier for the evaluation.
created_at: i64The Unix timestamp (in seconds) for when the eval was created.
data_source_config: DataSourceConfigConfiguration of data sources used in runs of the evaluation.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
name: StringThe name of the evaluation.
object: StringThe object type.
testing_criteria: Vec<TestingCriterion>A list of testing criteria.