pub struct ResultCounts {
pub errored: i64,
pub failed: i64,
pub passed: i64,
pub total: i64,
}Expand description
Counters summarizing the outcomes of the evaluation run.
Fields
errored: i64Number of output items that resulted in an error.
failed: i64Number of output items that failed to pass the evaluation.
passed: i64Number of output items that passed the evaluation.
total: i64Total number of executed output items.