RunRetrieveResponse

Struct RunRetrieveResponse 

pub struct RunRetrieveResponse {
Show 14 fields pub id: String, pub created_at: i64, pub data_source: DataSource, pub error: EvalAPIError, pub eval_id: String, pub metadata: Option<Value>, pub model: String, pub name: String, pub object: String, pub per_model_usage: Vec<PerModelUsage>, pub per_testing_criteria_results: Vec<PerTestingCriteriaResult>, pub report_url: String, pub result_counts: ResultCounts, pub status: String,
}
A schema representing an evaluation run.

Fields

id: String

Unique identifier for the evaluation run.

created_at: i64

Unix timestamp (in seconds) when the evaluation run was created.

data_source: DataSource

Information about the run’s data source.

error: EvalAPIError

An object representing an error response from the Eval API.

eval_id: String

The identifier of the associated evaluation.

metadata: Option<Value>

Set of 16 key-value pairs that can be attached to an object.

model: String

The model that is evaluated, if applicable.

name: String

The name of the evaluation run.

object: String

The type of the object. Always “eval.run”.

per_model_usage: Vec<PerModelUsage>

Usage statistics for each model during the evaluation run.

per_testing_criteria_results: Vec<PerTestingCriteriaResult>

Results per testing criteria applied during the evaluation run.

report_url: String

The URL to the rendered evaluation run report on the UI dashboard.

result_counts: ResultCounts

Counters summarizing the outcomes of the evaluation run.

status: String

The status of the evaluation run.