pub struct SamplingParams {
pub max_completion_tokens: Option<i64>,
pub reasoning_effort: Option<Value>,
pub response_format: Option<SamplingParamsResponseFormat>,
pub seed: Option<i64>,
pub temperature: Option<f64>,
pub tools: Option<Vec<Value>>,
pub top_p: Option<f64>,
}Fields
max_completion_tokens: Option<i64>The maximum number of tokens in the generated output.
reasoning_effort: Option<Value>Constrains effort on reasoning for
response_format: Option<SamplingParamsResponseFormat>An object specifying the format that the model must output.
seed: Option<i64>A seed value to initialize the randomness, during sampling.
temperature: Option<f64>A higher temperature increases randomness in the outputs.
tools: Option<Vec<Value>>A list of tools the model may call.
top_p: Option<f64>An alternative to temperature for nucleus sampling; 1.0 includes all tokens.