pub struct TestingCriterionLabelModel {
pub input: Vec<TestingCriterionLabelModelInput>,
pub labels: Value,
pub model: String,
pub name: String,
pub passing_labels: Value,
pub type_: String,
}Expand description
A LabelModelGrader object which uses a model to assign labels to each item
Fields
input: Vec<TestingCriterionLabelModelInput>A list of chat messages forming the prompt or context.
labels: ValueThe labels to classify to each item in the evaluation.
model: StringThe model to use for the evaluation. Must support structured outputs.
name: StringThe name of the grader.
passing_labels: ValueThe labels that indicate a passing result. Must be a subset of labels.
type_: StringThe object type, which is always label_model.