pub struct FineTuningJobWandbIntegrationObject {
pub type_: String,
pub wandb: FineTuningJobWandbIntegration,
}Fields
type_: StringThe type of the integration being enabled for the fine-tuning job
wandb: FineTuningJobWandbIntegrationThe settings for your integration with Weights and Biases.