pub struct IntegrationWandb {
pub project: String,
pub entity: Option<String>,
pub name: Option<String>,
pub tags: Option<Value>,
}Expand description
The settings for your integration with Weights and Biases.
Fields
project: StringThe name of the project that the new run will be created under.
entity: Option<String>The entity to use for the run.
name: Option<String>A display name to set for the run.
A list of tags to be attached to the newly created run.