pub struct JobCreateParams {
pub model: Option<String>,
pub training_file: String,
pub hyperparameters: Option<Hyperparameters>,
pub integrations: Option<Vec<Integration>>,
pub metadata: Option<Value>,
pub method: Option<Method>,
pub seed: Option<i64>,
pub suffix: Option<String>,
pub validation_file: Option<String>,
}Fields
model: Option<String>The name of the model to fine-tune.
training_file: StringThe ID of an uploaded file that contains training data.
hyperparameters: Option<Hyperparameters>The hyperparameters used for the fine-tuning job. This value is now deprecated
integrations: Option<Vec<Integration>>A list of integrations to enable for your fine-tuning job.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
method: Option<Method>The method used for fine-tuning.
seed: Option<i64>The seed controls the reproducibility of the job.
suffix: Option<String>A string of up to 64 characters that will be added to your fine-tuned model
validation_file: Option<String>The ID of an uploaded file that contains validation data.