pub struct PythonGrader {
pub name: String,
pub source: String,
pub type_: String,
pub image_tag: Option<String>,
}Expand description
A PythonGrader object that runs a python script on the input.
Fields
name: StringThe name of the grader.
source: StringThe source code of the python script.
type_: StringThe object type, which is always python.
image_tag: Option<String>The image tag to use for the python script.