pub struct SamplingParams {
pub max_completions_tokens: Option<i64>,
pub reasoning_effort: Option<Value>,
pub seed: Option<i64>,
pub temperature: Option<f64>,
pub top_p: Option<f64>,
}Expand description
The sampling parameters for the model.
Fields
max_completions_tokens: Option<i64>The maximum number of tokens the grader model may generate in its response.
reasoning_effort: Option<Value>Constrains effort on reasoning for
seed: Option<i64>A seed value to initialize the randomness, during sampling.
temperature: Option<f64>A higher temperature increases randomness in the outputs.
top_p: Option<f64>An alternative to temperature for nucleus sampling; 1.0 includes all tokens.