pub struct ImageCreateVariationParams {
pub image: Value,
pub model: Option<String>,
pub n: Option<i64>,
pub response_format: Option<ImageCreateVariationParamsResponseFormat>,
pub size: Option<ImageCreateVariationParamsSize>,
pub user: Option<String>,
}Fields
image: ValueThe image to use as the basis for the variation(s).
model: Option<String>The model to use for image generation.
n: Option<i64>The number of images to generate. Must be between 1 and 10.
response_format: Option<ImageCreateVariationParamsResponseFormat>The format in which the generated images are returned.
size: Option<ImageCreateVariationParamsSize>The size of the generated images.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor