pub struct ImageEditCompletedEvent {
pub b64_json: String,
pub background: ImageEditCompletedEventBackground,
pub created_at: i64,
pub output_format: ImageEditCompletedEventOutputFormat,
pub quality: ImageEditCompletedEventQuality,
pub size: ImageEditCompletedEventSize,
pub type_: String,
pub usage: Usage,
}Expand description
Emitted when image editing has completed and the final image is available.
Fields
b64_json: StringBase64-encoded final edited image data, suitable for rendering as an image.
background: ImageEditCompletedEventBackgroundThe background setting for the edited image.
created_at: i64The Unix timestamp when the event was created.
output_format: ImageEditCompletedEventOutputFormatThe output format for the edited image.
quality: ImageEditCompletedEventQualityThe quality setting for the edited image.
size: ImageEditCompletedEventSizeThe size of the edited image.
type_: StringThe type of the event. Always image_edit.completed.
usage: UsageFor the GPT image models only, the token usage information for the image