ImageEditParamsBase

Struct ImageEditParamsBase 

pub struct ImageEditParamsBase {
Show 14 fields pub image: Value, pub prompt: String, pub background: Option<ImageEditParamsBaseBackground>, pub input_fidelity: Option<ImageEditParamsBaseInputFidelity>, pub mask: Option<Value>, pub model: Option<String>, pub n: Option<i64>, pub output_compression: Option<i64>, pub output_format: Option<ImageEditParamsBaseOutputFormat>, pub partial_images: Option<i64>, pub quality: Option<ImageEditParamsBaseQuality>, pub response_format: Option<ImageEditParamsBaseResponseFormat>, pub size: Option<ImageEditParamsBaseSize>, pub user: Option<String>,
}

Fields

image: Value

The image(s) to edit. Must be a supported image file or an array of images.

prompt: String

A text description of the desired image(s).

background: Option<ImageEditParamsBaseBackground>

Allows to set transparency for the background of the generated image(s). This

input_fidelity: Option<ImageEditParamsBaseInputFidelity>

Control how much effort the model will exert to match the style and features,

mask: Option<Value>

An additional image whose fully transparent areas (e.g.

model: Option<String>

The model to use for image generation. Defaults to gpt-image-1.5.

n: Option<i64>

The number of images to generate. Must be between 1 and 10.

output_compression: Option<i64>

The compression level (0-100%) for the generated images.

output_format: Option<ImageEditParamsBaseOutputFormat>

The format in which the generated images are returned.

partial_images: Option<i64>

The number of partial images to generate.

quality: Option<ImageEditParamsBaseQuality>

The quality of the image that will be generated for GPT image models.

response_format: Option<ImageEditParamsBaseResponseFormat>

The format in which the generated images are returned.

size: Option<ImageEditParamsBaseSize>

The size of the generated images.

user: Option<String>

A unique identifier representing your end-user, which can help OpenAI to monitor