pub struct ImageEditPartialImageEvent {
pub b64_json: String,
pub background: ImageEditPartialImageEventBackground,
pub created_at: i64,
pub output_format: ImageEditPartialImageEventOutputFormat,
pub partial_image_index: i64,
pub quality: ImageEditPartialImageEventQuality,
pub size: ImageEditPartialImageEventSize,
pub type_: String,
}Expand description
Emitted when a partial image is available during image editing streaming.
Fields
b64_json: StringBase64-encoded partial image data, suitable for rendering as an image.
background: ImageEditPartialImageEventBackgroundThe background setting for the requested edited image.
created_at: i64The Unix timestamp when the event was created.
output_format: ImageEditPartialImageEventOutputFormatThe output format for the requested edited image.
partial_image_index: i640-based index for the partial image (streaming).
quality: ImageEditPartialImageEventQualityThe quality setting for the requested edited image.
size: ImageEditPartialImageEventSizeThe size of the requested edited image.
type_: StringThe type of the event. Always image_edit.partial_image.