pub struct ImageGenPartialImageEvent {
pub b64_json: String,
pub background: ImageGenPartialImageEventBackground,
pub created_at: i64,
pub output_format: ImageGenPartialImageEventOutputFormat,
pub partial_image_index: i64,
pub quality: ImageGenPartialImageEventQuality,
pub size: ImageGenPartialImageEventSize,
pub type_: String,
}Expand description
Emitted when a partial image is available during image generation streaming.
Fields
b64_json: StringBase64-encoded partial image data, suitable for rendering as an image.
background: ImageGenPartialImageEventBackgroundThe background setting for the requested image.
created_at: i64The Unix timestamp when the event was created.
output_format: ImageGenPartialImageEventOutputFormatThe output format for the requested image.
partial_image_index: i640-based index for the partial image (streaming).
quality: ImageGenPartialImageEventQualityThe quality setting for the requested image.
size: ImageGenPartialImageEventSizeThe size of the requested image.
type_: StringThe type of the event. Always image_generation.partial_image.