pub struct ImageGenerateParamsBase {Show 13 fields
pub prompt: String,
pub background: Option<ImageGenerateParamsBaseBackground>,
pub model: Option<String>,
pub moderation: Option<ImageGenerateParamsBaseModeration>,
pub n: Option<i64>,
pub output_compression: Option<i64>,
pub output_format: Option<ImageGenerateParamsBaseOutputFormat>,
pub partial_images: Option<i64>,
pub quality: Option<ImageGenerateParamsBaseQuality>,
pub response_format: Option<ImageGenerateParamsBaseResponseFormat>,
pub size: Option<ImageGenerateParamsBaseSize>,
pub style: Option<ImageGenerateParamsBaseStyle>,
pub user: Option<String>,
}Fields
prompt: StringA text description of the desired image(s).
background: Option<ImageGenerateParamsBaseBackground>Allows to set transparency for the background of the generated image(s). This
model: Option<String>The model to use for image generation.
moderation: Option<ImageGenerateParamsBaseModeration>Control the content-moderation level for images generated by the GPT image
n: Option<i64>The number of images to generate.
output_compression: Option<i64>The compression level (0-100%) for the generated images.
output_format: Option<ImageGenerateParamsBaseOutputFormat>The format in which the generated images are returned.
partial_images: Option<i64>The number of partial images to generate.
quality: Option<ImageGenerateParamsBaseQuality>The quality of the image that will be generated.
response_format: Option<ImageGenerateParamsBaseResponseFormat>The format in which generated images with dall-e-2 and dall-e-3 are
size: Option<ImageGenerateParamsBaseSize>The size of the generated images.
style: Option<ImageGenerateParamsBaseStyle>The style of the generated images.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor