pub struct Usage {
pub input_tokens: i64,
pub input_tokens_details: UsageInputTokensDetails,
pub output_tokens: i64,
pub total_tokens: i64,
}Expand description
For the GPT image models only, the token usage information for the image generation.
Fields
input_tokens: i64The number of tokens (images and text) in the input prompt.
input_tokens_details: UsageInputTokensDetailsThe input tokens detailed information for the image generation.
output_tokens: i64The number of image tokens in the output image.
total_tokens: i64The total number of tokens (images and text) used for the image generation.