pub struct UsageInputTokensDetails {
pub image_tokens: i64,
pub text_tokens: i64,
}Expand description
The input tokens detailed information for the image generation.
Fields
image_tokens: i64The number of image tokens in the input prompt.
text_tokens: i64The number of text tokens in the input prompt.