pub struct UsageOutputTokensDetails {
pub image_tokens: i64,
pub text_tokens: i64,
}Expand description
The output token details for the image generation.
Fields
image_tokens: i64The number of image output tokens generated by the model.
text_tokens: i64The number of text output tokens generated by the model.