pub struct AudioInputTurnDetectionServerVad {
pub type_: String,
pub create_response: Option<bool>,
pub idle_timeout_ms: Option<i64>,
pub interrupt_response: Option<bool>,
pub prefix_padding_ms: Option<i64>,
pub silence_duration_ms: Option<i64>,
pub threshold: Option<f64>,
}Expand description
Server-side voice activity detection (VAD) which flips on when user speech is detected and off after a period of silence.
Fields
type_: StringType of turn detection, server_vad to turn on simple Server VAD.
create_response: Option<bool>Whether or not to automatically generate a response when a VAD stop event
idle_timeout_ms: Option<i64>Optional timeout after which a model response will be triggered automatically.
interrupt_response: Option<bool>Whether or not to automatically interrupt (cancel) any ongoing response with
prefix_padding_ms: Option<i64>Used only for server_vad mode.
silence_duration_ms: Option<i64>Used only for server_vad mode.
threshold: Option<f64>Used only for server_vad mode.