pub struct ClientSecretCreateResponse {
pub expires_at: i64,
pub session: Session,
pub value: String,
}Expand description
Response from creating a session and client secret for the Realtime API.
Fields
expires_at: i64Expiration timestamp for the client secret, in seconds since epoch.
session: SessionThe session configuration for either a realtime or transcription session.
value: StringThe generated client secret value.