pub struct ConversationItemAdded {
pub event_id: String,
pub item: ConversationItem,
pub type_: String,
pub previous_item_id: Option<String>,
}Expand description
Sent by the server when an Item is added to the default Conversation.
Fields
event_id: StringThe unique ID of the server event.
item: ConversationItemA single item within a Realtime conversation.
type_: StringThe event type, must be conversation.item.added.
previous_item_id: Option<String>The ID of the item that precedes this one, if any.