pub struct ConversationItemRetrieveEvent {
pub item_id: String,
pub type_: String,
pub event_id: Option<String>,
}Expand description
Send this event when you want to retrieve the server’s representation of a specific item in the conversation history. This is useful, for example, to inspect user audio after noise cancellation and VAD.
Fields
item_id: StringThe ID of the item to retrieve.
type_: StringThe event type, must be conversation.item.retrieve.
event_id: Option<String>Optional client-generated ID used to identify this event.