pub struct InputAudioBufferCommittedEvent {
pub event_id: String,
pub item_id: String,
pub type_: String,
pub previous_item_id: Option<String>,
}Expand description
Returned when an input audio buffer is committed, either by the client or
Fields
event_id: StringThe unique ID of the server event.
item_id: StringThe ID of the user message item that will be created.
type_: StringThe event type, must be input_audio_buffer.committed.
previous_item_id: Option<String>The ID of the preceding item after which the new item will be inserted. Can be