pub struct RealtimeConversationContent {
pub audio: Option<String>,
pub text: Option<String>,
pub transcript: Option<String>,
pub type_: Option<RealtimeConversationContentType>,
}Fields
audio: Option<String>Base64-encoded audio bytes, these will be parsed as the format specified in the
text: Option<String>The text content.
transcript: Option<String>The transcript of the audio content, this will always be present if the output
type_: Option<RealtimeConversationContentType>The content type, output_text or output_audio depending on the session