pub struct RealtimeConversationItemFunctionCallOutput {
pub call_id: String,
pub output: String,
pub type_: String,
pub id: Option<String>,
pub object: Option<String>,
pub status: Option<RealtimeConversationItemFunctionCallOutputStatus>,
}Expand description
A function call output item in a Realtime conversation.
Fields
call_id: StringThe ID of the function call this output is for.
output: StringThe output of the function call, this is free text and can contain any
type_: StringThe type of the item. Always function_call_output.
id: Option<String>The unique ID of the item.
object: Option<String>Identifier for the API object being returned - always realtime.item.
status: Option<RealtimeConversationItemFunctionCallOutputStatus>The status of the item. Has no effect on the conversation.