pub struct RealtimeResponse {
pub id: Option<String>,
pub audio: Option<Audio>,
pub conversation_id: Option<String>,
pub max_output_tokens: Option<String>,
pub metadata: Option<Value>,
pub object: Option<String>,
pub output: Option<Vec<ConversationItem>>,
pub output_modalities: Option<Vec<Value>>,
pub status: Option<RealtimeResponseStatus>,
pub status_details: Option<RealtimeResponseStatus>,
pub usage: Option<RealtimeResponseUsage>,
}Expand description
The response resource.
Fields
id: Option<String>The unique ID of the response, will look like resp_1234.
audio: Option<Audio>Configuration for audio output.
conversation_id: Option<String>Which conversation the response is added to, determined by the conversation
max_output_tokens: Option<String>Maximum number of output tokens for a single assistant response, inclusive of
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
object: Option<String>The object type, must be realtime.response.
output: Option<Vec<ConversationItem>>The list of output items generated by the response.
output_modalities: Option<Vec<Value>>The set of modalities the model used to respond, currently the only possible
status: Option<RealtimeResponseStatus>The final status of the response (completed, cancelled, failed, or
status_details: Option<RealtimeResponseStatus>Additional details about the status.
usage: Option<RealtimeResponseUsage>Usage statistics for the Response, this will correspond to billing.