pub struct RealtimeSessionCreateRequest {
pub type_: String,
pub audio: Option<RealtimeAudioConfig>,
pub include: Option<Vec<String>>,
pub instructions: Option<String>,
pub max_output_tokens: Option<String>,
pub model: Option<String>,
pub output_modalities: Option<Vec<Value>>,
pub prompt: Option<Value>,
pub tool_choice: Option<RealtimeToolChoiceConfig>,
pub tools: Option<RealtimeToolsConfig>,
pub tracing: Option<RealtimeTracingConfig>,
pub truncation: Option<RealtimeTruncation>,
}Expand description
Realtime session object configuration.
Fields
type_: StringThe type of session to create. Always realtime for the Realtime API.
audio: Option<RealtimeAudioConfig>Configuration for input and output audio.
include: Option<Vec<String>>Additional fields to include in server outputs.
instructions: Option<String>The default system instructions (i.e.
max_output_tokens: Option<String>Maximum number of output tokens for a single assistant response, inclusive of
model: Option<String>The Realtime model used for this session.
output_modalities: Option<Vec<Value>>The set of modalities the model can respond with.
prompt: Option<Value>Reference to a prompt template and its variables.
tool_choice: Option<RealtimeToolChoiceConfig>How the model chooses tools.
tools: Option<RealtimeToolsConfig>Tools available to the model.
tracing: Option<RealtimeTracingConfig>Realtime API can write session traces to the
truncation: Option<RealtimeTruncation>When the number of tokens in a conversation exceeds the model’s input token