pub struct RealtimeTranscriptionSessionCreateResponse {
pub id: String,
pub object: String,
pub type_: String,
pub audio: Option<Audio>,
pub expires_at: Option<i64>,
pub include: Option<Vec<String>>,
}Expand description
A Realtime transcription session configuration object.
Fields
id: StringUnique identifier for the session that looks like sess_1234567890abcdef.
object: StringThe object type. Always realtime.transcription_session.
type_: StringThe type of session. Always transcription for transcription sessions.
audio: Option<Audio>Configuration for input audio for the session.
expires_at: Option<i64>Expiration timestamp for the session, in seconds since epoch.
include: Option<Vec<String>>Additional fields to include in server outputs.