pub struct ResponseAudioDeltaEvent {
pub content_index: i64,
pub delta: String,
pub event_id: String,
pub item_id: String,
pub output_index: i64,
pub response_id: String,
pub type_: String,
}Expand description
Returned when the model-generated audio is updated.
Fields
content_index: i64The index of the content part in the item’s content array.
delta: StringBase64-encoded audio data delta.
event_id: StringThe unique ID of the server event.
item_id: StringThe ID of the item.
output_index: i64The index of the output item in the response.
response_id: StringThe ID of the response.
type_: StringThe event type, must be response.output_audio.delta.