pub struct ResponseContentPartAddedEvent {
pub content_index: i64,
pub event_id: String,
pub item_id: String,
pub output_index: i64,
pub part: ContentPartPart,
pub response_id: String,
pub type_: String,
}Expand description
Returned when a new content part is added to an assistant message item during
Fields
content_index: i64The index of the content part in the item’s content array.
event_id: StringThe unique ID of the server event.
item_id: StringThe ID of the item to which the content part was added.
output_index: i64The index of the output item in the response.
part: ContentPartPartThe content part that was added.
response_id: StringThe ID of the response.
type_: StringThe event type, must be response.content_part.added.