pub struct ResponseMcpCallInProgress {
pub event_id: String,
pub item_id: String,
pub output_index: i64,
pub type_: String,
}Expand description
Returned when an MCP tool call has started and is in progress.
Fields
event_id: StringThe unique ID of the server event.
item_id: StringThe ID of the MCP tool call item.
output_index: i64The index of the output item in the response.
type_: StringThe event type, must be response.mcp_call.in_progress.