pub struct ResponseOutputItemDoneEvent {
pub event_id: String,
pub item: ConversationItem,
pub output_index: i64,
pub response_id: String,
pub type_: String,
}Expand description
Returned when an Item is done streaming.
Fields
event_id: StringThe unique ID of the server event.
item: ConversationItemA single item within a Realtime conversation.
output_index: i64The index of the output item in the Response.
response_id: StringThe ID of the Response to which the item belongs.
type_: StringThe event type, must be response.output_item.done.