pub struct TracingTracingConfiguration {
pub group_id: Option<String>,
pub metadata: Option<Value>,
pub workflow_name: Option<String>,
}Expand description
Granular configuration for tracing.
Fields
group_id: Option<String>The group id to attach to this trace to enable filtering and grouping in the
metadata: Option<Value>The arbitrary metadata to attach to this trace to enable filtering in the Traces
workflow_name: Option<String>The name of the workflow to attach to this trace.