pub struct ActionClick {
pub button: ActionClickButton,
pub type_: String,
pub x: i64,
pub y: i64,
}Expand description
A click action.
Fields
Indicates which mouse button was pressed during the click.
type_: StringSpecifies the event type. For a click action, this property is always click.
x: i64The x-coordinate where the click occurred.
y: i64The y-coordinate where the click occurred.