pub struct ActionKeypress {
pub keys: Vec<String>,
pub type_: String,
}Expand description
A collection of keypresses the model would like to perform.
Fields
keys: Vec<String>The combination of keys the model is requesting to be pressed.
type_: StringSpecifies the event type.