pub struct AnnotationContainerFileCitation {
pub container_id: String,
pub end_index: i64,
pub file_id: String,
pub filename: String,
pub start_index: i64,
pub type_: String,
}Expand description
A citation for a container file used to generate a model response.
Fields
container_id: StringThe ID of the container file.
end_index: i64The index of the last character of the container file citation in the message.
file_id: StringThe ID of the file.
filename: StringThe filename of the container file cited.
start_index: i64The index of the first character of the container file citation in the message.
type_: StringThe type of the container file citation. Always container_file_citation.