pub struct ApplyPatchCall {
pub call_id: String,
pub operation: ApplyPatchCallOperation,
pub status: ApplyPatchCallStatus,
pub type_: String,
pub id: Option<String>,
}Expand description
A tool call representing a request to create, delete, or update files using diff patches.
Fields
call_id: StringThe unique ID of the apply patch tool call generated by the model.
operation: ApplyPatchCallOperationThe specific create, delete, or update instruction for the apply_patch tool
status: ApplyPatchCallStatusThe status of the apply patch tool call. One of in_progress or completed.
type_: StringThe type of the item. Always apply_patch_call.
id: Option<String>The unique ID of the apply patch tool call.