pub struct ApplyPatchCallOperationCreateFile {
pub diff: String,
pub path: String,
pub type_: String,
}Expand description
Instruction for creating a new file via the apply_patch tool.
Fields
diff: StringUnified diff content to apply when creating the file.
path: StringPath of the file to create relative to the workspace root.
type_: StringThe operation type. Always create_file.