pub struct ApplyPatchCallOperationUpdateFile {
pub diff: String,
pub path: String,
pub type_: String,
}Expand description
Instruction for updating an existing file via the apply_patch tool.
Fields
diff: StringUnified diff content to apply to the existing file.
path: StringPath of the file to update relative to the workspace root.
type_: StringThe operation type. Always update_file.