pub struct ApplyPatchCallOutput {
pub call_id: String,
pub status: ApplyPatchCallOutputStatus,
pub type_: String,
pub id: Option<String>,
pub output: Option<String>,
}Expand description
The streamed output emitted by an apply patch tool call.
Fields
call_id: StringThe unique ID of the apply patch tool call generated by the model.
status: ApplyPatchCallOutputStatusThe status of the apply patch tool call output. One of completed or failed.
type_: StringThe type of the item. Always apply_patch_call_output.
id: Option<String>The unique ID of the apply patch tool call output.
output: Option<String>Optional human-readable log text from the apply patch tool (e.g., patch results