pub struct ComputerCallOutput {
pub call_id: String,
pub output: ResponseComputerToolCallOutputScreenshot,
pub type_: String,
pub id: Option<String>,
pub acknowledged_safety_checks: Option<Vec<ComputerCallOutputAcknowledgedSafetyCheck>>,
pub status: Option<ComputerCallOutputStatus>,
}Expand description
The output of a computer tool call.
Fields
call_id: StringThe ID of the computer tool call that produced the output.
output: ResponseComputerToolCallOutputScreenshotA computer screenshot image used with the computer use tool.
type_: StringThe type of the computer tool call output. Always computer_call_output.
id: Option<String>The ID of the computer tool call output.
acknowledged_safety_checks: Option<Vec<ComputerCallOutputAcknowledgedSafetyCheck>>The safety checks reported by the API that have been acknowledged by the
status: Option<ComputerCallOutputStatus>The status of the message input.