pub struct ContainerAuto {
pub type_: String,
pub file_ids: Option<Vec<String>>,
pub memory_limit: Option<ContainerAutoMemoryLimit>,
pub network_policy: Option<NetworkPolicy>,
pub skills: Option<Vec<Skill>>,
}Fields
type_: StringAutomatically creates a container for this request
file_ids: Option<Vec<String>>An optional list of uploaded files to make available to your code.
memory_limit: Option<ContainerAutoMemoryLimit>The memory limit for the container.
network_policy: Option<NetworkPolicy>Network access policy for the container.
skills: Option<Vec<Skill>>An optional list of skills referenced by id or inline data.