pub struct CustomTool {
pub name: String,
pub type_: String,
pub defer_loading: Option<bool>,
pub description: Option<String>,
pub format: Option<Value>,
}Expand description
A custom tool that processes input using a specified format.
Fields
name: StringThe name of the custom tool, used to identify it in tool calls.
type_: StringThe type of the custom tool. Always custom.
defer_loading: Option<bool>Whether this tool should be deferred and discovered via tool search.
description: Option<String>Optional description of the custom tool, used to provide more context.
format: Option<Value>The input format for the custom tool. Default is unconstrained text.