pub struct FunctionShellAction {
pub commands: Vec<String>,
pub max_output_length: Option<i64>,
pub timeout_ms: Option<i64>,
}Expand description
The shell commands and limits that describe how to run the tool call.
Fields
commands: Vec<String>max_output_length: Option<i64>Optional maximum number of characters to return from each command.
timeout_ms: Option<i64>Optional timeout in milliseconds for the commands.