pub struct FunctionShellOutput {
pub outcome: OutputOutcome,
pub stderr: String,
pub stdout: String,
pub created_by: Option<String>,
}Expand description
The content of a shell tool call output that was emitted.
Fields
outcome: OutputOutcomeRepresents either an exit outcome (with an exit code) or a timeout outcome for a
stderr: StringThe standard error output that was captured.
stdout: StringThe standard output that was captured.
created_by: Option<String>The identifier of the actor that created the item.