pub struct Message {
pub content: ResponseInputMessageContentList,
pub role: MessageRole,
pub status: Option<MessageStatus>,
pub type_: Option<String>,
}Expand description
A message input to the model with a role indicating instruction following
Fields
content: ResponseInputMessageContentListA list of one or many input items to the model, containing different content
role: MessageRoleThe role of the message input. One of user, system, or developer.
status: Option<MessageStatus>The status of item.
type_: Option<String>The type of the message input. Always set to message.