pub struct RankingOptions {
pub hybrid_search: Option<RankingOptionsHybridSearch>,
pub ranker: Option<RankingOptionsRanker>,
pub score_threshold: Option<f64>,
}Expand description
Ranking options for search.
Fields
hybrid_search: Option<RankingOptionsHybridSearch>Weights that control how reciprocal rank fusion balances semantic embedding
ranker: Option<RankingOptionsRanker>The ranker to use for the file search.
score_threshold: Option<f64>The score threshold for the file search, a number between 0 and 1.