pub struct ResponseApplyPatchToolCall {
pub id: String,
pub call_id: String,
pub operation: Operation,
pub status: ResponseApplyPatchToolCallStatus,
pub type_: String,
pub created_by: Option<String>,
}Expand description
A tool call that applies file diffs by creating, deleting, or updating files.
Fields
id: StringThe unique ID of the apply patch tool call.
call_id: StringThe unique ID of the apply patch tool call generated by the model.
operation: OperationOne of the create_file, delete_file, or update_file operations applied via
status: ResponseApplyPatchToolCallStatusThe status of the apply patch tool call. One of in_progress or completed.
type_: StringThe type of the item. Always apply_patch_call.
created_by: Option<String>The ID of the entity that created this tool call.