pub struct ResponseApplyPatchToolCallOutput {
pub id: String,
pub call_id: String,
pub status: ResponseApplyPatchToolCallOutputStatus,
pub type_: String,
pub created_by: Option<String>,
pub output: Option<String>,
}Expand description
The output emitted by an apply patch tool call.
Fields
id: StringThe unique ID of the apply patch tool call output.
call_id: StringThe unique ID of the apply patch tool call generated by the model.
status: ResponseApplyPatchToolCallOutputStatusThe status of the apply patch tool call output. One of completed or failed.
type_: StringThe type of the item. Always apply_patch_call_output.
created_by: Option<String>The ID of the entity that created this tool call output.
output: Option<String>Optional textual output returned by the apply patch tool.