pub struct ResponseCodeInterpreterCallCompletedEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when the code interpreter call is completed.
Fields
item_id: StringThe unique identifier of the code interpreter tool call item.
output_index: i64The index of the output item in the response for which the code interpreter call
sequence_number: i64The sequence number of this event, used to order streaming events.
type_: StringThe type of the event. Always response.code_interpreter_call.completed.