pub struct ResponseCodeInterpreterToolCall {
pub id: String,
pub code: Option<String>,
pub container_id: String,
pub outputs: Option<Vec<FunctionShellOutput>>,
pub status: ResponseCodeInterpreterToolCallStatus,
pub type_: String,
}Expand description
A tool call to run code.
Fields
id: StringThe unique ID of the code interpreter tool call.
code: Option<String>The code to run, or null if not available.
container_id: StringThe ID of the container used to run the code.
outputs: Option<Vec<FunctionShellOutput>>The outputs generated by the code interpreter, such as logs or images. Can be
status: ResponseCodeInterpreterToolCallStatusThe status of the code interpreter tool call.
type_: StringThe type of the code interpreter tool call. Always code_interpreter_call.