pub struct ResponseCompactParams {
pub model: Option<String>,
pub input: Option<String>,
pub instructions: Option<String>,
pub previous_response_id: Option<String>,
pub prompt_cache_key: Option<String>,
}Fields
model: Option<String>Model ID used to generate the response, like gpt-5 or o3.
input: Option<String>Text, image, or file inputs to the model, used to generate a response
instructions: Option<String>A system (or developer) message inserted into the model’s context. When used
previous_response_id: Option<String>The unique ID of the previous response to the model.
prompt_cache_key: Option<String>A key to use when reading from or writing to the prompt cache.