pub struct ResponseComputerToolCallOutputItem {
pub id: String,
pub call_id: String,
pub output: ResponseComputerToolCallOutputScreenshot,
pub type_: String,
pub acknowledged_safety_checks: Option<Vec<AcknowledgedSafetyCheck>>,
pub status: Option<ResponseComputerToolCallOutputItemStatus>,
}Fields
id: StringThe unique ID of the computer call tool output.
call_id: StringThe ID of the computer tool call that produced the output.
output: ResponseComputerToolCallOutputScreenshotA computer screenshot image used with the computer use tool.
type_: StringThe type of the computer tool call output. Always computer_call_output.
acknowledged_safety_checks: Option<Vec<AcknowledgedSafetyCheck>>The safety checks reported by the API that have been acknowledged by the
status: Option<ResponseComputerToolCallOutputItemStatus>The status of the message input.