pub struct ResponseComputerToolCallOutputScreenshot {
pub type_: String,
pub file_id: Option<String>,
pub image_url: Option<String>,
}Expand description
A computer screenshot image used with the computer use tool.
Fields
type_: StringSpecifies the event type.
file_id: Option<String>The identifier of an uploaded file that contains the screenshot.
image_url: Option<String>The URL of the screenshot image.