pub struct ResponseContentPartAddedEvent {
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub part: ReasoningSummaryPart,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when a new content part is added.
Fields
content_index: i64The index of the content part that was added.
item_id: StringThe ID of the output item that the content part was added to.
output_index: i64The index of the output item that the content part was added to.
part: ReasoningSummaryPartThe content part that was added.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always response.content_part.added.