pub struct ResponseCustomToolCall {
pub call_id: String,
pub input: String,
pub name: String,
pub type_: String,
pub id: Option<String>,
pub namespace: Option<String>,
}Expand description
A call to a custom tool created by the model.
Fields
call_id: StringAn identifier used to map this custom tool call to a tool call output.
input: StringThe input for the custom tool call generated by the model.
name: StringThe name of the custom tool being called.
type_: StringThe type of the custom tool call. Always custom_tool_call.
id: Option<String>The unique ID of the custom tool call in the OpenAI platform.
namespace: Option<String>The namespace of the custom tool being called.