pub struct ResponseCustomToolCallInputDoneEvent {
pub input: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Event indicating that input for a custom tool call is complete.
Fields
input: StringThe complete input data for the custom tool call.
item_id: StringUnique identifier for the API item associated with this event.
output_index: i64The index of the output this event applies to.
sequence_number: i64The sequence number of this event.
type_: StringThe event type identifier.