pub struct ResponseCustomToolCallOutput {
pub call_id: String,
pub output: String,
pub type_: String,
pub id: Option<String>,
}Expand description
The output of a custom tool call from your code, being sent back to the model.
Fields
call_id: StringThe call ID, used to map this custom tool call output to a custom tool call.
output: StringThe output from the custom tool call generated by your code. Can be a string or
type_: StringThe type of the custom tool call output. Always custom_tool_call_output.
id: Option<String>The unique ID of the custom tool call output in the OpenAI platform.