pub struct ResponseFileSearchCallCompletedEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when a file search call is completed (results found).
Fields
item_id: StringThe ID of the output item that the file search call is initiated.
output_index: i64The index of the output item that the file search call is initiated.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always response.file_search_call.completed.