pub struct ResponseFormatTextJSONSchemaConfig {
pub name: String,
pub schema_: HashMap<String, Value>,
pub type_: String,
pub description: Option<String>,
pub strict: Option<bool>,
}Expand description
JSON Schema response format.
Fields
name: StringThe name of the response format.
schema_: HashMap<String, Value>The schema for the response format, described as a JSON Schema object. Learn how
type_: StringThe type of response format being defined. Always json_schema.
description: Option<String>A description of what the response format is for, used by the model to determine
strict: Option<bool>Whether to enable strict schema adherence when generating the output. If set to