pub struct ResponseFunctionShellCallOutputContent {
pub outcome: Outcome,
pub stderr: String,
pub stdout: String,
}Expand description
Captured stdout and stderr for a portion of a shell tool call output.
Fields
outcome: OutcomeThe exit or timeout outcome associated with this shell call.
stderr: StringCaptured stderr output for the shell call.
stdout: StringCaptured stdout output for the shell call.