pub struct ResponseFunctionShellToolCall {
pub id: String,
pub action: FunctionShellAction,
pub call_id: String,
pub environment: Option<Environment>,
pub status: ResponseFunctionShellToolCallStatus,
pub type_: String,
pub created_by: Option<String>,
}Expand description
A tool call that executes one or more shell commands in a managed environment.
Fields
id: StringThe unique ID of the shell tool call.
action: FunctionShellActionThe shell commands and limits that describe how to run the tool call.
call_id: StringThe unique ID of the shell tool call generated by the model.
environment: Option<Environment>Represents the use of a local environment to perform shell actions.
status: ResponseFunctionShellToolCallStatusThe status of the shell call.
type_: StringThe type of the item. Always shell_call.
created_by: Option<String>The ID of the entity that created this tool call.