pub struct ResponseFunctionShellToolCallOutput {
pub id: String,
pub call_id: String,
pub max_output_length: Option<i64>,
pub output: Vec<FunctionShellOutput>,
pub status: ResponseFunctionShellToolCallOutputStatus,
pub type_: String,
pub created_by: Option<String>,
}Expand description
The output of a shell tool call that was emitted.
Fields
id: StringThe unique ID of the shell call output.
call_id: StringThe unique ID of the shell tool call generated by the model.
max_output_length: Option<i64>The maximum length of the shell command output.
output: Vec<FunctionShellOutput>An array of shell call output contents
status: ResponseFunctionShellToolCallOutputStatusThe status of the shell call output.
type_: StringThe type of the shell call output. Always shell_call_output.
created_by: Option<String>The identifier of the actor that created the item.