pub struct ResponseFunctionToolCall {
pub arguments: String,
pub call_id: String,
pub name: String,
pub type_: String,
pub id: Option<String>,
pub namespace: Option<String>,
pub status: Option<ResponseFunctionToolCallStatus>,
}Expand description
A tool call to run a function.
Fields
arguments: StringA JSON string of the arguments to pass to the function.
call_id: StringThe unique ID of the function tool call generated by the model.
name: StringThe name of the function to run.
type_: StringThe type of the function tool call. Always function_call.
id: Option<String>The unique ID of the function tool call.
namespace: Option<String>The namespace of the function to run.
status: Option<ResponseFunctionToolCallStatus>The status of the item.