pub struct ResponseFunctionToolCallOutputItem {
pub id: String,
pub call_id: String,
pub output: String,
pub type_: String,
pub status: Option<ResponseFunctionToolCallOutputItemStatus>,
}Fields
id: StringThe unique ID of the function call tool output.
call_id: StringThe unique ID of the function tool call generated by the model.
output: StringThe output from the function call generated by your code. Can be a string or an
type_: StringThe type of the function tool call output. Always function_call_output.
status: Option<ResponseFunctionToolCallOutputItemStatus>The status of the item.