pub struct ResponseImageGenCallInProgressEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when an image generation tool call is in progress.
Fields
item_id: StringThe unique identifier of the image generation item being processed.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of the image generation item being processed.
type_: StringThe type of the event. Always ‘response.image_generation_call.in_progress’.