pub struct ResponseImageGenCallPartialImageEvent {
pub item_id: String,
pub output_index: i64,
pub partial_image_b64: String,
pub partial_image_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when a partial image is available during image generation streaming.
Fields
item_id: StringThe unique identifier of the image generation item being processed.
output_index: i64The index of the output item in the response’s output array.
partial_image_b64: StringBase64-encoded partial image data, suitable for rendering as an image.
partial_image_index: i640-based index for the partial image (backend is 1-based, but this is 0-based for
sequence_number: i64The sequence number of the image generation item being processed.
type_: StringThe type of the event. Always ‘response.image_generation_call.partial_image’.