pub struct ResponseInputFileContent {
pub type_: String,
pub file_data: Option<String>,
pub file_id: Option<String>,
pub file_url: Option<String>,
pub filename: Option<String>,
}Expand description
A file input to the model.
Fields
type_: StringThe type of the input item. Always input_file.
file_data: Option<String>The base64-encoded data of the file to be sent to the model.
file_id: Option<String>The ID of the file to be sent to the model.
file_url: Option<String>The URL of the file to be sent to the model.
filename: Option<String>The name of the file to be sent to the model.