pub struct ResponseInputImage {
pub detail: ResponseInputImageDetail,
pub type_: String,
pub file_id: Option<String>,
pub image_url: Option<String>,
}Expand description
An image input to the model.
Fields
detail: ResponseInputImageDetailThe detail level of the image to be sent to the model.
type_: StringThe type of the input item. Always input_image.
file_id: Option<String>The ID of the file to be sent to the model.
image_url: Option<String>The URL of the image to be sent to the model.