pub struct ResponseInputImageContent {
pub type_: String,
pub detail: Option<ResponseInputImageContentDetail>,
pub file_id: Option<String>,
pub image_url: Option<String>,
}Expand description
An image input to the model.
Fields
type_: StringThe type of the input item. Always input_image.
detail: Option<ResponseInputImageContentDetail>The detail level of the image to be sent to the model.
file_id: Option<String>The ID of the file to be sent to the model.
image_url: Option<String>The URL of the image to be sent to the model.