pub struct ResponseMcpListToolsInProgressEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when the system is in the process of retrieving the list of available MCP tools.
Fields
item_id: StringThe ID of the MCP tool call item that is being processed.
output_index: i64The index of the output item that is being processed.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always ‘response.mcp_list_tools.in_progress’.