pub struct ResponseOutputTextAnnotationAddedEvent {
pub annotation: Value,
pub annotation_index: i64,
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when an annotation is added to output text content.
Fields
annotation: ValueThe annotation object being added. (See annotation schema for details.)
annotation_index: i64The index of the annotation within the content part.
content_index: i64The index of the content part within the output item.
item_id: StringThe unique identifier of the item to which the annotation is being added.
output_index: i64The index of the output item in the response’s output array.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always ‘response.output_text.annotation.added’.