pub struct ResponseReasoningSummaryPartDoneEvent {
pub item_id: String,
pub output_index: i64,
pub part: ReasoningSummaryPart,
pub sequence_number: i64,
pub summary_index: i64,
pub type_: String,
}Expand description
Emitted when a reasoning summary part is completed.
Fields
item_id: StringThe ID of the item this summary part is associated with.
output_index: i64The index of the output item this summary part is associated with.
part: ReasoningSummaryPartThe completed summary part.
sequence_number: i64The sequence number of this event.
summary_index: i64The index of the summary part within the reasoning summary.
type_: StringThe type of the event. Always response.reasoning_summary_part.done.