pub struct ResponseReasoningTextDoneEvent {
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub text: String,
pub type_: String,
}Expand description
Emitted when a reasoning text is completed.
Fields
content_index: i64The index of the reasoning content part.
item_id: StringThe ID of the item this reasoning text is associated with.
output_index: i64The index of the output item this reasoning text is associated with.
sequence_number: i64The sequence number of this event.
text: StringThe full text of the completed reasoning content.
type_: StringThe type of the event. Always response.reasoning_text.done.