pub struct ResponseRefusalDeltaEvent {
pub content_index: i64,
pub delta: String,
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when there is a partial refusal text.
Fields
content_index: i64The index of the content part that the refusal text is added to.
delta: StringThe refusal text that is added.
item_id: StringThe ID of the output item that the refusal text is added to.
output_index: i64The index of the output item that the refusal text is added to.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always response.refusal.delta.