pub struct ResponseRefusalDoneEvent {
pub content_index: i64,
pub item_id: String,
pub output_index: i64,
pub refusal: String,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when refusal text is finalized.
Fields
content_index: i64The index of the content part that the refusal text is finalized.
item_id: StringThe ID of the output item that the refusal text is finalized.
output_index: i64The index of the output item that the refusal text is finalized.
refusal: StringThe refusal text that is finalized.
sequence_number: i64The sequence number of this event.
type_: StringThe type of the event. Always response.refusal.done.