pub struct ResponseTextDoneEvent {
pub content_index: i64,
pub item_id: String,
pub logprobs: Vec<Logprob>,
pub output_index: i64,
pub sequence_number: i64,
pub text: String,
pub type_: String,
}Expand description
Emitted when text content is finalized.
Fields
content_index: i64The index of the content part that the text content is finalized.
item_id: StringThe ID of the output item that the text content is finalized.
logprobs: Vec<Logprob>The log probabilities of the tokens in the delta.
output_index: i64The index of the output item that the text content is finalized.
sequence_number: i64The sequence number for this event.
text: StringThe text content that is finalized.
type_: StringThe type of the event. Always response.output_text.done.