pub struct ResponseToolSearchCall {
pub id: String,
pub arguments: Value,
pub call_id: Option<String>,
pub execution: ResponseToolSearchCallExecution,
pub status: ResponseToolSearchCallStatus,
pub type_: String,
pub created_by: Option<String>,
}Fields
id: StringThe unique ID of the tool search call item.
arguments: ValueArguments used for the tool search call.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: ResponseToolSearchCallExecutionWhether tool search was executed by the server or by the client.
status: ResponseToolSearchCallStatusThe status of the tool search call item that was recorded.
type_: StringThe type of the item. Always tool_search_call.
created_by: Option<String>The identifier of the actor that created the item.