pub struct ResponseToolSearchOutputItem {
pub id: String,
pub call_id: Option<String>,
pub execution: ResponseToolSearchOutputItemExecution,
pub status: ResponseToolSearchOutputItemStatus,
pub tools: Vec<Tool>,
pub type_: String,
pub created_by: Option<String>,
}Fields
id: StringThe unique ID of the tool search output item.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: ResponseToolSearchOutputItemExecutionWhether tool search was executed by the server or by the client.
status: ResponseToolSearchOutputItemStatusThe status of the tool search output item that was recorded.
tools: Vec<Tool>The loaded tool definitions returned by tool search.
type_: StringThe type of the item. Always tool_search_output.
created_by: Option<String>The identifier of the actor that created the item.