pub struct ResponseWebSearchCallInProgressEvent {
pub item_id: String,
pub output_index: i64,
pub sequence_number: i64,
pub type_: String,
}Expand description
Emitted when a web search call is initiated.
Fields
item_id: StringUnique ID for the output item associated with the web search call.
output_index: i64The index of the output item that the web search call is associated with.
sequence_number: i64The sequence number of the web search call being processed.
type_: StringThe type of the event. Always response.web_search_call.in_progress.