pub struct ShellCall {
pub action: ShellCallAction,
pub call_id: String,
pub type_: String,
pub id: Option<String>,
pub environment: Option<ShellCallEnvironment>,
pub status: Option<ShellCallStatus>,
}Expand description
A tool representing a request to execute one or more shell commands.
Fields
action: ShellCallActionThe shell commands and limits that describe how to run the tool call.
call_id: StringThe unique ID of the shell tool call generated by the model.
type_: StringThe type of the item. Always shell_call.
id: Option<String>The unique ID of the shell tool call.
environment: Option<ShellCallEnvironment>The environment to execute the shell commands in.
status: Option<ShellCallStatus>The status of the shell call.