pub struct ShellCallAction {
pub commands: Vec<String>,
pub max_output_length: Option<i64>,
pub timeout_ms: Option<i64>,
}Expand description
The shell commands and limits that describe how to run the tool call.
Fields
commands: Vec<String>Ordered shell commands for the execution environment to run.
max_output_length: Option<i64>Maximum number of UTF-8 characters to capture from combined stdout and stderr
timeout_ms: Option<i64>Maximum wall-clock time in milliseconds to allow the shell commands to run.