pub struct ShellCallOutput {
pub call_id: String,
pub output: Vec<ResponseFunctionShellCallOutputContent>,
pub type_: String,
pub id: Option<String>,
pub max_output_length: Option<i64>,
pub status: Option<ShellCallOutputStatus>,
}Expand description
The streamed output items emitted by a shell tool call.
Fields
call_id: StringThe unique ID of the shell tool call generated by the model.
output: Vec<ResponseFunctionShellCallOutputContent>Captured chunks of stdout and stderr output, along with their associated
type_: StringThe type of the item. Always shell_call_output.
id: Option<String>The unique ID of the shell tool call output.
max_output_length: Option<i64>The maximum number of UTF-8 characters captured for this shell call’s combined
status: Option<ShellCallOutputStatus>The status of the shell call output.