pub struct ToolSearchCall {
pub arguments: Value,
pub type_: String,
pub id: Option<String>,
pub call_id: Option<String>,
pub execution: Option<ToolSearchCallExecution>,
pub status: Option<ToolSearchCallStatus>,
}Fields
arguments: ValueThe arguments supplied to the tool search call.
type_: StringThe item type. Always tool_search_call.
id: Option<String>The unique ID of this tool search call.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: Option<ToolSearchCallExecution>Whether tool search was executed by the server or by the client.
status: Option<ToolSearchCallStatus>The status of the tool search call.