pub struct UserLocation {
pub type_: String,
pub city: Option<String>,
pub country: Option<String>,
pub region: Option<String>,
pub timezone: Option<String>,
}Expand description
The user’s location.
Fields
type_: StringThe type of location approximation. Always approximate.
city: Option<String>Free text input for the city of the user, e.g. San Francisco.
country: Option<String>The two-letter ISO country code of
region: Option<String>Free text input for the region of the user, e.g. California.
timezone: Option<String>The IANA timezone of the