pub struct WebSearchPreviewTool {
pub type_: WebSearchPreviewToolType,
pub search_content_types: Option<Vec<Value>>,
pub search_context_size: Option<WebSearchPreviewToolSearchContextSize>,
pub user_location: Option<UserLocation>,
}Expand description
This tool searches the web for relevant results to use in a response.
Fields
type_: WebSearchPreviewToolTypeThe type of the web search tool.
search_content_types: Option<Vec<Value>>search_context_size: Option<WebSearchPreviewToolSearchContextSize>High level guidance for the amount of context window space to use for the
user_location: Option<UserLocation>The user’s location.