pub struct WebSearchTool {
pub type_: WebSearchToolType,
pub filters: Option<Filters>,
pub search_context_size: Option<WebSearchToolSearchContextSize>,
pub user_location: Option<UserLocation>,
}Expand description
Search the Internet for sources related to the prompt.
Fields
type_: WebSearchToolTypeThe type of the web search tool.
filters: Option<Filters>Filters for the search.
search_context_size: Option<WebSearchToolSearchContextSize>High level guidance for the amount of context window space to use for the
user_location: Option<UserLocation>The approximate location of the user.