Module shared

Module shared 

shared types — auto-managed by py2rust.

Re-exports

pub use common::*;
pub use pagination::*;

Modules

common
pagination

Structs

ComparisonFilter
A filter used to compare a specified attribute key to a given value using a defined comparison operation.
CompoundFilter
Combine multiple filters using and or or.
ErrorObject
FunctionDefinition
Grammar
A grammar defined by the user.
JSONSchema
Structured Outputs configuration options, including a JSON Schema.
Reasoning
gpt-5 and o-series models only
ResponseFormatJSONObject
JSON object response format.
ResponseFormatJSONSchema
JSON Schema response format.
ResponseFormatText
Default response format. Used to generate text responses.
ResponseFormatTextGrammar
A custom grammar for the model to follow when generating text.
ResponseFormatTextPython
Configure the model to generate valid Python code.
Text
Unconstrained free-form text.

Enums

AllModels
ChatModel
ComparisonFilterType
CompoundFilterType
GrammarSyntax
ReasoningEffort
ReasoningGenerateSummary
ReasoningSummary
ResponsesModel

Type Aliases

CustomToolInputFormat
Filter
FunctionParameters
Metadata