pub struct JSONSchema {
pub name: String,
pub description: Option<String>,
pub schema_: Option<HashMap<String, Value>>,
pub strict: Option<bool>,
}Expand description
Structured Outputs configuration options, including a JSON Schema.
Fields
name: StringThe name of the response format.
description: Option<String>A description of what the response format is for, used by the model to determine
schema_: Option<HashMap<String, Value>>The schema for the response format, described as a JSON Schema object. Learn how
strict: Option<bool>Whether to enable strict schema adherence when generating the output. If set to