pub struct CompletionCreateParamsBase {Show 34 fields
pub messages: Vec<Value>,
pub model: String,
pub audio: Option<Value>,
pub frequency_penalty: Option<f64>,
pub function_call: Option<FunctionCall>,
pub functions: Option<Vec<Value>>,
pub logit_bias: Option<HashMap<String, i64>>,
pub logprobs: Option<bool>,
pub max_completion_tokens: Option<i64>,
pub max_tokens: Option<i64>,
pub metadata: Option<Value>,
pub modalities: Option<Vec<Value>>,
pub n: Option<i64>,
pub parallel_tool_calls: Option<bool>,
pub prediction: Option<Value>,
pub presence_penalty: Option<f64>,
pub prompt_cache_key: Option<String>,
pub prompt_cache_retention: Option<CompletionCreateParamsBasePromptCacheRetention>,
pub reasoning_effort: Option<Value>,
pub response_format: Option<ResponseFormat>,
pub safety_identifier: Option<String>,
pub seed: Option<i64>,
pub service_tier: Option<CompletionCreateParamsBaseServiceTier>,
pub stop: Option<Value>,
pub store: Option<bool>,
pub stream_options: Option<Value>,
pub temperature: Option<f64>,
pub tool_choice: Option<Value>,
pub tools: Option<Vec<Value>>,
pub top_logprobs: Option<i64>,
pub top_p: Option<f64>,
pub user: Option<String>,
pub verbosity: Option<CompletionCreateParamsBaseVerbosity>,
pub web_search_options: Option<WebSearchOptions>,
}Fields
messages: Vec<Value>A list of messages comprising the conversation so far.
model: StringModel ID used to generate the response, like gpt-4o or o3.
audio: Option<Value>Parameters for audio output.
frequency_penalty: Option<f64>Number between -2.0 and 2.0.
function_call: Option<FunctionCall>Deprecated in favor of tool_choice.
functions: Option<Vec<Value>>Deprecated in favor of tools.
logit_bias: Option<HashMap<String, i64>>Modify the likelihood of specified tokens appearing in the completion.
logprobs: Option<bool>Whether to return log probabilities of the output tokens or not.
max_completion_tokens: Option<i64>An upper bound for the number of tokens that can be generated for a completion,
max_tokens: Option<i64>The maximum number of tokens that can be generated in the chat
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
modalities: Option<Vec<Value>>Output types that you would like the model to generate. Most models are capable
n: Option<i64>How many chat completion choices to generate for each input message.
parallel_tool_calls: Option<bool>Whether to enable
prediction: Option<Value>Static predicted output content, such as the content of a text file that is
presence_penalty: Option<f64>Number between -2.0 and 2.0.
prompt_cache_key: Option<String>Used by OpenAI to cache responses for similar requests to optimize your cache
prompt_cache_retention: Option<CompletionCreateParamsBasePromptCacheRetention>The retention policy for the prompt cache.
reasoning_effort: Option<Value>Constrains effort on reasoning for
response_format: Option<ResponseFormat>An object specifying the format that the model must output.
safety_identifier: Option<String>A stable identifier used to help detect users of your application that may be
seed: Option<i64>This feature is in Beta. If specified, our system will make a best effort to
service_tier: Option<CompletionCreateParamsBaseServiceTier>Specifies the processing type used for serving the request.
stop: Option<Value>Not supported with latest reasoning models o3 and o4-mini.
store: Option<bool>Whether or not to store the output of this chat completion request for use in
stream_options: Option<Value>Options for streaming response. Only set this when you set stream: true.
temperature: Option<f64>What sampling temperature to use, between 0 and 2.
tool_choice: Option<Value>Controls which (if any) tool is called by the model. none means the model will
tools: Option<Vec<Value>>A list of tools the model may call.
top_logprobs: Option<i64>An integer between 0 and 20 specifying the number of most likely tokens to
top_p: Option<f64>An alternative to sampling with temperature, called nucleus sampling, where the
user: Option<String>This field is being replaced by safety_identifier and prompt_cache_key.
verbosity: Option<CompletionCreateParamsBaseVerbosity>Constrains the verbosity of the model’s response.
web_search_options: Option<WebSearchOptions>This tool searches the web for relevant results to use in a response. Learn more