pub struct RunRetrieveResponse {Show 14 fields
pub id: String,
pub created_at: i64,
pub data_source: DataSource,
pub error: EvalAPIError,
pub eval_id: String,
pub metadata: Option<Value>,
pub model: String,
pub name: String,
pub object: String,
pub per_model_usage: Vec<PerModelUsage>,
pub per_testing_criteria_results: Vec<PerTestingCriteriaResult>,
pub report_url: String,
pub result_counts: ResultCounts,
pub status: String,
}Expand description
A schema representing an evaluation run.
Fields
id: StringUnique identifier for the evaluation run.
created_at: i64Unix timestamp (in seconds) when the evaluation run was created.
data_source: DataSourceInformation about the run’s data source.
error: EvalAPIErrorAn object representing an error response from the Eval API.
eval_id: StringThe identifier of the associated evaluation.
metadata: Option<Value>Set of 16 key-value pairs that can be attached to an object.
model: StringThe model that is evaluated, if applicable.
name: StringThe name of the evaluation run.
object: StringThe type of the object. Always “eval.run”.
per_model_usage: Vec<PerModelUsage>Usage statistics for each model during the evaluation run.
per_testing_criteria_results: Vec<PerTestingCriteriaResult>Results per testing criteria applied during the evaluation run.
report_url: StringThe URL to the rendered evaluation run report on the UI dashboard.
result_counts: ResultCountsCounters summarizing the outcomes of the evaluation run.
status: StringThe status of the evaluation run.