pub struct InputAudioBufferCommitEvent {
pub type_: String,
pub event_id: Option<String>,
}Expand description
Send this event to commit the user input audio buffer, which will create a new user message item in the conversation. This event will produce an error if the input audio buffer is empty. When in Server VAD mode, the client does not need to send this event, the server will commit the audio buffer automatically.
Fields
type_: StringThe event type, must be input_audio_buffer.commit.
event_id: Option<String>Optional client-generated ID used to identify this event.