pub struct RealtimeConversationItemSystemMessage {
pub content: Vec<RealtimeConversationContent>,
pub role: String,
pub type_: String,
pub id: Option<String>,
pub object: Option<String>,
pub status: Option<RealtimeConversationItemSystemMessageStatus>,
}Expand description
A system message in a Realtime conversation can be used to provide additional context or instructions to the model. This is similar but distinct from the instruction prompt provided at the start of a conversation, as system messages can be added at any point in the conversation. For major changes to the conversation’s behavior, use instructions, but for smaller updates (e.g. “the user is now asking about a different topic”), use system messages.
Fields
content: Vec<RealtimeConversationContent>The content of the message.
role: StringThe role of the message sender. Always system.
type_: StringThe type of the item. Always message.
id: Option<String>The unique ID of the item.
object: Option<String>Identifier for the API object being returned - always realtime.item.
status: Option<RealtimeConversationItemSystemMessageStatus>The status of the item. Has no effect on the conversation.