pub struct InputTokenCountParams {
pub conversation: Option<Conversation>,
pub input: Option<String>,
pub instructions: Option<String>,
pub model: Option<String>,
pub parallel_tool_calls: Option<bool>,
pub previous_response_id: Option<String>,
pub reasoning: Option<Value>,
pub text: Option<Text>,
pub tool_choice: Option<ToolChoice>,
pub tools: Option<Vec<Value>>,
pub truncation: Option<InputTokenCountParamsTruncation>,
}Fields
conversation: Option<Conversation>The conversation that this response belongs to.
input: Option<String>Text, image, or file inputs to the model, used to generate a response
instructions: Option<String>A system (or developer) message inserted into the model’s context. When used
model: Option<String>Model ID used to generate the response, like gpt-4o or o3.
parallel_tool_calls: Option<bool>Whether to allow the model to run tool calls in parallel.
previous_response_id: Option<String>The unique ID of the previous response to the model.
reasoning: Option<Value>gpt-5 and o-series models only Configuration options for
text: Option<Text>Configuration options for a text response from the model.
tool_choice: Option<ToolChoice>Controls which tool the model should use, if any.
tools: Option<Vec<Value>>An array of tools the model may call while generating a response.
truncation: Option<InputTokenCountParamsTruncation>The truncation strategy to use for the model response.