shared types — auto-managed by py2rust.
Re-exports
pub use common::*;pub use pagination::*;
Modules
Structs
- Comparison
Filter - A filter used to compare a specified attribute key to a given value using a defined comparison operation.
- Compound
Filter - Combine multiple filters using
andoror. - Error
Object - Function
Definition - Grammar
- A grammar defined by the user.
- JSON
Schema - Structured Outputs configuration options, including a JSON Schema.
- Reasoning
- gpt-5 and o-series models only
- Response
FormatJSON Object - JSON object response format.
- Response
FormatJSON Schema - JSON Schema response format.
- Response
Format Text - Default response format. Used to generate text responses.
- Response
Format Text Grammar - A custom grammar for the model to follow when generating text.
- Response
Format Text Python - Configure the model to generate valid Python code.
- Text
- Unconstrained free-form text.
Enums
- AllModels
- Chat
Model - Comparison
Filter Type - Compound
Filter Type - Grammar
Syntax - Reasoning
Effort - Reasoning
Generate Summary - Reasoning
Summary - Responses
Model